@@ -95,34 +95,5 @@ module.exports=function(db,config,validator,jvm,manifest){
         prefix:'/css'
     }));
 
-    //config static
-    app.use(express.static(work_dir+'/public'));
-
-    app.use(function(req, res,next) {
-      var url = req.url;
-      if(url.indexOf('api')>=0){
-         // res.sendFile(work_dir+'/public/index.html',404);
-          //resst.send('Page Not Found',404);
-         // var err = new Error('Not Found');
-         // err.status = 404;
-         // next(err);
-
-          res.status(404);
-          res.send('Page Not Found');
-     
-      } else if(url.indexOf('.')>=0){
-         // var err = new Error('Not Found');
-         // err.status = 404;
-         // next(err);
-          res.status(404);
-          res.send('Page Not Found');
-      }
-      else{
-          res.sendFile(work_dir+'/public/index.html',404);
-      }
-      
-      
-     // next();
-   });
     return app;
 }
